@@ -27,7 +27,7 @@
 #include "action_data/action_data_group.h"
 #include "action_data/simple_action_data.h"
 
-#include <KDebug>
+#include <QDebug>
 #include <KUrl>
 
 #include <QtCore/QSignalMapper>
@@ -180,6 +180,7 @@ void HotkeysTreeViewContextMenu::createTriggerMenus(
             this, SLOT(newWindowTriggerActionAction(int)) );
         }
 
+        /* - disable the UI for adding mouse gestures as they don't work and haven't since 5.0
     if (triggerTypes & KHotKeys::Trigger::GestureTriggerType)
         {
         QSignalMapper *mapper = new QSignalMapper(this);
@@ -191,7 +192,7 @@ void HotkeysTreeViewContextMenu::createTriggerMenus(
         connect(
             mapper, SIGNAL(mapped(int)),
             this, SLOT(newMouseGestureTriggerActionAction(int)) );
-        }
+        }*/
 
     addMenu(newMenu);
     }
